luciole/location

Functions

pub fn get() -> Chainable(Dynamic)

Get the global window.location object of the page that is currently active.

Yields the location object with the following properties:

  • hash
  • host
  • hostname
  • href
  • origin
  • pathname
  • port
  • protocol
  • search
  • toString

See Cypress Documentation - location.

pub fn hash() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s hash string.

See Cypress Documentation - location.

pub fn host() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s host string.

See Cypress Documentation - location.

pub fn hostname() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s hostname string.

See Cypress Documentation - location.

pub fn href() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s href string.

See Cypress Documentation - location.

pub fn origin() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s origin string.

See Cypress Documentation - location.

pub fn pathname() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s pathname string.

See Cypress Documentation - location.

pub fn port() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s port string.

See Cypress Documentation - location.

pub fn protocol() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s protocol string.

See Cypress Documentation - location.

pub fn search() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s search string.

See Cypress Documentation - location.

pub fn super_domain() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s super domain string.

See Cypress Documentation - location.

pub fn super_domain_origin() -> Chainable(String)

Get the global window.location object of the page that is currently active.

Yields the location’s super domain origin string.

See Cypress Documentation - location.

Search Document