luciole/location
Functions
pub fn get() -> Chainable(Dynamic)
Get the global window.location object of the page that is currently active.
Yields the location object with the following properties:
hashhosthostnamehreforiginpathnameportprotocolsearchtoString
pub fn hash() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s hash string.
pub fn host() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s host string.
pub fn hostname() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s hostname string.
pub fn href() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s href string.
pub fn origin() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s origin string.
pub fn pathname() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s pathname string.
pub fn port() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s port string.
pub fn protocol() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s protocol string.
pub fn search() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s search string.
pub fn super_domain() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s super domain string.
pub fn super_domain_origin() -> Chainable(String)
Get the global window.location object of the page that is currently active.
Yields the location’s super domain origin string.